==> ficus-0.2.0157.tgz: ficus/pages/scaffold/NewScaffoldForeperson.php <==
<?php 
/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */
/*
 * Copyright 2004-2007 Project Guarana Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
/**
 * @package ficus.pages.scaffold
 */
/**
 * @file NewScaffoldForeperson.php
 * @brief new scaffold foreperson
 * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
 * @version $Id: NewScaffoldForeperson.php 2 2007-07-11 10:37:48Z ishitoya $
 */

require_once("ficus/config/Registry.php");

/**
 * @class Ficus_NewScaffoldForeperson
 */
class Ficus_NewScaffoldForeperson extends Ficus_AbstractScaffoldForeperson{
    /**
     * new 
     * @param $args array of arguments
     */
    public function doDefault(){
        if($this->mediator->request()->hasEntity()){
            $entity = $this->mediator->request()->entity();
        }else{
            $entity = $this->mediator->daoManager()->entity();
        }
        return $this->buildNew($entity);
    }

    /**
     * new 
     * @param $args array of arguments
     */
    public function doChildren(){
        $entity = $this->mediator->getEntityFromRequest();
        return $this->buildNew($entity);
    }

    /**
     * buildNew
     */
    protected function buildNew($entity){
        $transition = null;
        if($this->mediator->request()->has(self::KEY_TRANSITION)){
            $transition = $this->mediator->request()->extractAsString(
                                                         self::KEY_TRANSITION);
            $this->mediator->table()->setCurrentTransition($transition);
        }
        $container = $this->mediator->daoManager()->getContainer($entity);
        
        $organizer = $this->mediator->organizerFactory()->createNewOrganizer();
        $organizer->setItemTemplate("row");
        $organizer->setEntityTemplate("table");

        $container->addOrganizers($organizer);

        $transition = $this->mediator->table()->getNextTransition($transition);
        if($transition == null){
            $this->mediator->formBean()->setDo(self::DO_CONFIRM);
        }else{
            $this->mediator->formBean()->setDo(self::DO_CHILDREN);
            $this->mediator->formBean()->setTransition($transition);
        }
        return $container->build();
    }

    /**
     * new 
     * @param $args array of arguments
     */
    public function doConfirm(){
        $entity = $this->mediator->getEntityFromRequest();
        $container = $this->mediator->daoManager()->getContainer($entity);
        
        $organizer =
            $this->mediator->organizerFactory()->createViewOrganizer();

        $organizer->setItemTemplate("row");
        $organizer->setEntityTemplate("table");

        $container->addOrganizers($organizer);
        $container->addOrganizers(
            $this->mediator->organizerFactory()->createHiddenOrganizer());
        $this->mediator->formBean()->setDo(self::DO_SUBMIT);
        return $container->build();
    }

    /**
     * new 
     * @param $args array of arguments
     */
    public function doSubmit(){
        $entity = $this->mediator->getEntityFromRequest();
        $container = $this->mediator->daoManager()->getContainer($entity);
        
        $organizer =
            $this->mediator->organizerFactory()->createViewOrganizer();

        $organizer->setItemTemplate("row");
        $organizer->setEntityTemplate("table");

        $container->addOrganizers($organizer);

        $entity->insert();

        return $container->build();
    }
}    
?>

==> ficus-0.2.0161.tgz: ficus/pages/scaffold/NewScaffoldForeperson.php <==
<?php 
/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */
/*
 * Copyright 2004-2007 Project Guarana Development Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
/**
 * @package ficus.pages.scaffold
 */
/**
 * @file NewScaffoldForeperson.php
 * @brief new scaffold foreperson
 * @author <a href="mailto:kent@guarana.cc">ISHITOYA Kentaro</a>
 * @version $Id: NewScaffoldForeperson.php 14 2007-07-18 14:55:12Z ishitoya $
 */

require_once("ficus/config/Registry.php");

/**
 * @class Ficus_NewScaffoldForeperson
 */
class Ficus_NewScaffoldForeperson extends Ficus_AbstractScaffoldForeperson{
    /**
     * new 
     * @param $args array of arguments
     */
    public function doDefault(){
        if(is_null($this->mediator->entity())){
            $entity = $this->mediator->daoManager()->entity();
        }else{
            $entity = $this->mediator->entity();
        }
        return $this->buildNew($entity);
    }

    /**
     * new 
     * @param $args array of arguments
     */
    public function doChildren(){
        $entity = $this->mediator->getEntityFromRequest();
        return $this->buildNew($entity);
    }

    /**
     * new 
     * @param $args array of arguments
     */
    public function doConfirm(){
        $entity = $this->mediator->getEntityFromRequest();
        $container = $this->mediator->getContainer($entity);
        
        $organizer =
            $this->mediator->organizerFactory()->createViewOrganizer();

        $organizer->setItemTemplate("row");
        $organizer->setEntityTemplate("table");

        $container->addOrganizers($organizer);
        $container->addOrganizers(
            $this->mediator->organizerFactory()->createHiddenOrganizer());
        $this->mediator->formBean()->setDo(self::DO_SUBMIT);
        return $container->build();
    }

    /**
     * new 
     * @param $args array of arguments
     */
    public function doSubmit(){
        $entity = $this->mediator->getEntityFromRequest();
        $container = $this->mediator->getContainer($entity);
        
        $organizer =
            $this->mediator->organizerFactory()->createViewOrganizer();

        $organizer->setItemTemplate("row");
        $organizer->setEntityTemplate("table");

        $container->addOrganizers($organizer);

        $entity->insert();

        return $container->build();
    }

    /**
     * buildNew
     */
    protected function buildNew($entity){
        $transition = null;
        if($this->mediator->request()->has(self::KEY_TRANSITION)){
            $transition = $this->mediator->request()->extractAsString(
                                                         self::KEY_TRANSITION);
            $this->mediator->table()->setCurrentTransition($transition);
        }
        $container = $this->mediator->getContainer($entity);
        
        $organizer = $this->mediator->organizerFactory()->createNewOrganizer();
        $organizer->setItemTemplate("row");
        $organizer->setEntityTemplate("table");

        $container->addOrganizers($organizer);

        $transition = $this->mediator->table()->getNextTransition($transition);
        if($transition == null){
            $this->mediator->formBean()->setDo(self::DO_CONFIRM);
        }else{
            $this->mediator->formBean()->setDo(self::DO_CHILDREN);
            $this->mediator->formBean()->setTransition($transition);
        }
        return $container->build();
    }
}    
?>
